@@ -186,11 +186,22 @@ public class OXCommunicationException extends USMException {
 
 	@Override
 	public String getErrorMessage() {
-		String message = getMessage();
-		if (message == null)
-			message = _serverResponse;
+		String message = super.getMessage();
+		if (isServerResponseSet()) {
+		    if (message == null) {
+		        message = _serverResponse;
+		    }
+		    else {
+		        message = super.getMessage() + " server-response: " + _serverResponse;
+		    }
+		}
 		return message;
 	}
+	
+    @Override
+    public String getMessage() {
+        return getErrorMessage();
+    }
 
 	@Override
 	protected void addStacktrace(Throwable t, JSONObject errorDetailsObject) {
