@@ -162,11 +162,11 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     @Override
     public void readFolder(Folder object, BitSet requestedFields) throws USMException {
         Session session = object.getSession();
-        if (LOG.isDebugEnabled())
-            LOG.debug(session + " Get folder" + object.getID());
         // Build parameter list
         Map<String, String> parameters = createCommonParameters(session, requestedFields);
         parameters.put(CommonConstants.ID, object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Get folder " + object.getID() + " with parameters: " + parameters.toString());        
         JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_GET, session, parameters);
         if (result.getResultType() == JSONResultType.Error) {
             checkConflictingChange(result.getJSONObject());
