@@ -96,12 +96,16 @@ public final class ParticipantIdentifier implements Serializable {
 		switch (_type) {
 			case 1:
 			case 2:
-			case 3:
 			case 4:
 				_id = jObject.getInt(ID);
 				_displayName = "";
 				_mail = "";
 				break;
+            case 3:
+                _id = jObject.getInt(ID);
+                _displayName = jObject.has(DISPLAY_NAME) ? (jObject.isNull(DISPLAY_NAME) ? "" : jObject.getString(DISPLAY_NAME)) : "";
+                _mail = jObject.has(MAIL) ?(jObject.isNull(MAIL) ? "" : jObject.getString(MAIL)) : "";
+                break;
 			case 5:
 				_id = 0;
 				_displayName = jObject.has(DISPLAY_NAME) ? (jObject.isNull(DISPLAY_NAME) ? "" : jObject.getString(DISPLAY_NAME)) : "";
@@ -168,7 +172,7 @@ public final class ParticipantIdentifier implements Serializable {
 		JSONObject result = new JSONObject();
 		result.put(ID, _id);
 		result.put(TYPE, _type);
-		if (_type == 5) {
+		if (_type == 5 || _type == 3) {
 			result.put(DISPLAY_NAME, _displayName);
 			result.put(MAIL, _mail);
 		}
