@@ -58,28 +58,28 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.exception.OXException;
-import com.openexchange.usm.api.database.DatabaseAccess;
+import com.openexchange.usm.api.database.DatabaseAccessWithNoTimeoutSupport;
 import com.openexchange.usm.api.database.EncapsulatedConnection;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.util.SQLToolkit;
 import com.openexchange.usm.util.Toolkit;
 
-public class OXDBService implements DatabaseAccess {
+public class OXDBService implements DatabaseAccessWithNoTimeoutSupport {
 
     private static final String UNHEX = "UNHEX";
 
     private static final String HEX = "HEX";
 
-    private DatabaseService _delegate;
+    private final DatabaseService _delegate;
 
     private static final Log LOG = LogFactory.getLog(OXDBService.class);
 
-    private ContextService _contextService;
+    private final ContextService _contextService;
 
     /**
      * Initializes a new {@link OXDBService}.
-     * 
+     *
      * @param contextService
      * @param databaseService
      */
@@ -91,22 +91,33 @@ public class OXDBService implements DatabaseAccess {
 
     @Override
     public void backReadOnly(int contextID, Connection connection) throws StorageAccessException {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug("Releasing read only JDBC Connection for " + contextID);
+        }
         _delegate.backReadOnly(contextID, connection);
     }
 
     @Override
     public void backWritable(int contextID, Connection connection) throws StorageAccessException {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug("Releasing read/write JDBC Connection for " + contextID);
+        }
         _delegate.backWritable(contextID, connection);
     }
 
+    @Override
+    public void backNoTimeout(int contextID, Connection connection) throws StorageAccessException {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Releasing no-timeout JDBC Connection for " + contextID);
+        }
+        _delegate.backForUpdateTask(contextID, connection);
+    }
+
     @Override
     public EncapsulatedConnection getReadOnly(int contextID) throws StorageAccessException {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug("Retrieving read only JDBC Connection for " + contextID);
+        }
         try {
             return new EncapsulatedConnection(this, _delegate.getReadOnly(contextID), contextID, true);
         } catch (OXException e) {
@@ -118,8 +129,9 @@ public class OXDBService implements DatabaseAccess {
 
     @Override
     public EncapsulatedConnection getWritable(int contextID) throws StorageAccessException {
-        if (LOG.isDebugEnabled())
+        if (LOG.isDebugEnabled()) {
             LOG.debug("Retrieving read/write JDBC Connection for " + contextID);
+        }
         try {
             return new EncapsulatedConnection(this, _delegate.getWritable(contextID), contextID, false);
         } catch (OXException e) {
@@ -129,6 +141,20 @@ public class OXDBService implements DatabaseAccess {
         }
     }
 
+    @Override
+    public EncapsulatedConnection getNoTimeout(int contextID) throws StorageAccessException {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Retrieving no-timeout JDBC Connection for " + contextID);
+        }
+        try {
+            return new EncapsulatedConnection(this, _delegate.getForUpdateTask(contextID), contextID, EncapsulatedConnection.Nature.NO_TIMEOUT);
+        } catch (OXException e) {
+            String errorMessage = "Couldn't get no-timeout connection for " + contextID;
+            LOG.error(errorMessage, e);
+            throw new StorageAccessException(USMDatabaseOXErrorCodes.GET_READ_WRITE_ERROR, errorMessage, e);
+        }
+    }
+
     @Override
     public void generateSequence(int contextID, String sequenceName) throws USMStorageException, StorageAccessException {
         EncapsulatedConnection con = getWritable(contextID);
