@@ -76,21 +76,17 @@ public class USMDeleteStoredProceduresUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-        int contextId = params.getContextId();
+        Connection con = params.getConnection();
         for (int i = 0; i < SEQUENCE_TABLES_NAMES.length; i++) {
-            Connection con = null;
             try {
-                con = _provider.getDatabaseService().getForUpdateTask(contextId);
                 String tablename = SEQUENCE_TABLES_NAMES[i];
-                if (procedureExists(tablename, con.getMetaData()))
+                if (procedureExists(tablename, con.getMetaData())) {
                     dropSequence(tablename, con, true);
+                }
             } catch (USMStorageException e) {
                 throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
             } catch (SQLException e) {
                 throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
-            } finally {
-                if (con != null)
-                    _provider.getDatabaseService().backWritable(contextId, con);
             }
         }
     }
@@ -100,22 +96,25 @@ public class USMDeleteStoredProceduresUpdateTaskV2 extends USMBaseUpdateTaskV2 {
         try {
             try {
                 stmt = con.createStatement();
-                if (isAutocommit)
+                if (isAutocommit) {
                     con.setAutoCommit(false);
+                }
                 stmt.execute(SQLToolkit.dropSequenceProcedure(sequenceName));
                 con.commit();
                 LOG.info("Dropping of sequence " + sequenceName + " successfully performed");
             } catch (SQLException e) {
-                if (isAutocommit)
+                if (isAutocommit) {
                     con.rollback();
+                }
                 if (e.getMessage().contains("alter routine command denied to user")) {
                     LOG.info("Dropping of sequence " + sequenceName + " was not possible. Probably it did not exist anyway.");
-                }
-                else
+                } else {
                     throw new USMStorageException(USMDatabaseOXErrorCodes.CREATE_SEQUENCE_ERROR, e.getMessage(), e);
+                }
             } finally {
-                if (isAutocommit)
+                if (isAutocommit) {
                     con.setAutoCommit(true);
+                }
                 Toolkit.close(stmt);
             }
         } catch (SQLException e) {
@@ -127,13 +126,15 @@ public class USMDeleteStoredProceduresUpdateTaskV2 extends USMBaseUpdateTaskV2 {
         ResultSet resultSet = null;
         try {
             resultSet = dbmd.getProcedures(null, null, "get_" + procedureName + "_id");
-            if (resultSet == null) return false;
+            if (resultSet == null) {
+                return false;
+            }
             return resultSet.next();
         } finally {
             Toolkit.close(resultSet);
         }
     }
-    
+
     @Override
     public String[] getDependencies() {
 		return new String[] { USMTablesUpdateTaskV2.class.getName() };
