@@ -173,6 +173,10 @@ public class DownloadDataHandler extends NormalCommandHandler {
         _object.setFieldContent(CONTACT_IMAGE_DATA, new Image());
         try {
             byte[] content = ((ContactContentType) _object.getContentType()).getPictureData(_object, "jpeg", Integer.MAX_VALUE);
+            if (content == null) {
+                _servlet.getJournal().debug("contact image couldn't be prepared for " + _id);
+                return noImageData();
+            }
             _realLength = Math.max(0L, Math.min(_requestedLength, content.length - _offset));
             _moreAvailable = _offset + _realLength < content.length;
             if (content.length != _realLength) {
@@ -188,15 +192,8 @@ public class DownloadDataHandler extends NormalCommandHandler {
             return new ResponseObject(_responseStatus, data);
         } catch (USMException e) {
             if (e instanceof OXCommunicationException && ((OXCommunicationException)e).getHttpStatusCode() == 406) {
-                _servlet.getJournal().debug("image not available for " + _id + "  " + e.getErrorMessage());
-                JSONObject data = new JSONObject();
-                try {
-                    data.put("data", "");
-                }
-                catch (JSONException ej) {
-                    // ignore
-                }
-                return new ResponseObject(ResponseStatusCode.SUCCESS, data);                
+                _servlet.getJournal().debug("contact image not available for " + _id + "  " + e.getErrorMessage());
+                return noImageData();
             }
             throw new USMJSONAPIException(
                 ConnectorBundleErrorCodes.DOWNLOAD_DATA_IMAGE_NOT_FOUND,
@@ -207,6 +204,17 @@ public class DownloadDataHandler extends NormalCommandHandler {
         }
     }
 
+    private ResponseObject noImageData() {
+        JSONObject data = new JSONObject();
+        try {
+            data.put("data", "");
+        }
+        catch (JSONException ej) {
+            // ignore
+        }
+        return new ResponseObject(ResponseStatusCode.SUCCESS, data);                        
+    }
+    
     private void skipOffset(ResourceInputStream is) throws IOException {
         long skipped =0L, remaining = _offset;
         
