@@ -66,7 +66,6 @@ import java.util.UUID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.log.LogProperties;
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.HttpSessionUtil;
@@ -130,10 +129,6 @@ public class LoginHandler extends BaseCommandHandler {
         }
         HttpSessionUtil.storeSession(getHttpSession(), randomHttpSessionID, usmSessionID);
 
-        LogProperties.put(LogProperties.Name.SESSION_SESSION_ID, _session.getSessionId());
-        LogProperties.put(LogProperties.Name.SESSION_CONTEXT_ID, _session.getContextId());
-        LogProperties.put(LogProperties.Name.SESSION_USER_ID, _session.getUserIdentifier());
-
         return new ResponseObject(ResponseStatusCode.SUCCESS, resultObject);
     }
 
