@@ -49,10 +49,10 @@
 
 package com.openexchange.groupware.settings.tree.modules.interfaces;
 
-import com.openexchange.groupware.settings.tree.AbstractModules;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.settings.tree.AbstractPermissions;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 
-public class USMActive extends AbstractModules {
+public class USMActive extends AbstractPermissions {
 
     /**
      * Default constructor.
@@ -73,9 +73,7 @@ public class USMActive extends AbstractModules {
      * {@inheritDoc}
      */
     @Override
-    protected boolean getModule(final UserConfiguration userConfig) {
-        if (userConfig != null)
-            return userConfig.hasUSM();
-        return false;
+    protected boolean hasPermission(UserPermissionBits permissionBits) {
+        return permissionBits.hasUSM();
     }
 }
