@@ -454,7 +454,7 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
             if (i == lastModifiedIndex)
                 continue;
             DataType<?> type = fields[i].getFieldType();
-            if (serverChange.isFieldModified(i)) {
+            if (serverChange.isFieldModified(i) && f.getFieldContent(i) != null && serverChange.getFieldContent(i) != null) {
                 if (!type.isEqual(f.getFieldContent(i), serverChange.getFieldContent(i))) {
                     if  (i == noteIndex) {
                         // we manipulate in AbstractSyncDelegate.simulateServerChangesForAppointments() the note with irrelevant changes 
